#======
# Copyright (c) IBM Corp. 2011, 2016.
# All rights reserved. This program is made available
# under the terms of the Eclipse Public License v1.0
# which accompanies this distribution, and is available at
# http://www.eclipse.org/legal/epl-v10.html
#=======

"""
Kernel command line arguments parsing and validation.
"""

from __future__ import absolute_import
import re

from configurator.logger import createLogger
from configurator.pkvmerror import PKVMError


KERNEL_CMDLINE_PATH = '/proc/cmdline'
args = {}


def __parseKernelCmdLine():
    """
    Parse kernel command line arguments

    Raises:
        PKVMError: Failed to open the command line file for reading.
    """
    logger = createLogger()
    try:
        with open(KERNEL_CMDLINE_PATH, 'rt') as f:
            content = f.read()
        logger.debug("Kernel boot command line:")
        for token in content.split():
            logger.debug(token)
            (key, _, value) = token.partition('=')
            if key not in args:
                args[key] = []
            args[key].append(value)
    except:
        raise PKVMError('067')


def validateRepositoryURLs(urls):
    """
    Check whether package repository URLs are valid.

    Args:
        urls ([str]): urls to package repositories.
    """
    for url in urls:
        if re.match('(https?|ftp|nfs)://', url) is None:
            raise PKVMError("068")

# These are run when the module is imported.
# Code in a module will only be run once, no matter how many times said module
# is imported.
__parseKernelCmdLine()
if 'repo' in args:
    validateRepositoryURLs(args['repo'])
